# MisskeyTypes (MiTypes)
Type definitions used in Misskey API responses.

## Install
```
$ pip install mitypes
```

### list of type definitions
- Note
- channel
- Poll
- drive
    - DriveFolder
    - DriveFile
        - df_property (DriveFile.properties)
- user
    - User
        - AvatarDecorations (User.avatarDecorations)
    - UserLite
        - AvatarDecorations (UserLite.avatarDecorations)